@@ -41,6 +41,12 @@ class ObjectivesCalculator(object):
         return {objective.name: objective.calculate_score(responses)
                 for objective in self.objectives}
 
+    def calculate_values(self, responses):
+        """Calculator the value of each objective"""
+
+        return {objective.name: objective.calculate_value(responses)
+                for objective in self.objectives}
+
     def __str__(self):
         return 'objectives:\n  %s' % '\n  '.join(
             [str(obj) for obj in self.objectives]) \
